@@ -1,14 +1,37 @@
-#' Model-based response estimates and uncertainty
+#' Model-based predictions
 #'
 #' @description
 #' After fitting a model, it is useful generate model-based estimates of the
 #' response variables for different combinations of predictor values. Such
-#' estimates can be used to make inferences about relationships between
-#' variables and to make predictions about individual cases.
+#' estimates can be used to make inferences about **relationships** between
+#' variables, to make predictions about individual cases, or to compare the
+#' **predicted** values against the observed data.
 #'
-#' Model-based response estimates and uncertainty can be generated for both the
-#' conditional average response values (the regression line or expectation) and
-#' for predictions about individual cases. See below for details.
+#' The `modelbased` package includes 4 "related" functions, that mostly differ in
+#' their default arguments (in particular, `data` and `predict`):
+#'
+#' - `estimate_prediction(data = NULL, predict = "prediction", ...)`
+#' - `estimate_expectation(data = NULL, predict = "expectation", ...)`
+#' - `estimate_relation(data = "grid", predict = "expectation", ...)`
+#' - `estimate_link(data = "grid", predict = "link", ...)`
+#'
+#' While they are all based on model-based predictions (using
+#' [insight::get_predicted()]), they differ in terms of the **type** of
+#' predictions they make by default. For instance, `estimate_prediction()` and
+#' `estimate_expectation()` return predictions for the original data used to fit
+#' the model, while `estimate_relation()` and `estimate_link()` return
+#' predictions on a [insight::get_datagrid()]. Similarly, `estimate_link`
+#' returns predictions on the link scale, while the others return predictions on
+#' the response scale. Note that the relevance of these differences depends on
+#' the model family (for instance, for linear models, `estimate_relation` is
+#' equivalent to `estimate_link()`, since there is no difference between the
+#' link-scale and the response scale).
+#'
+#' Note that you can run [`plot()`][visualisation_recipe.estimate_predicted] on
+#' the output of these functions to get some visual insights (see the
+#' [plotting examples][visualisation_recipe.estimate_predicted]).
+#'
+#' See the **details** section below for details about the different possibilities.
 #'
 #' @section Expected (average) values:
 #'
@@ -81,7 +104,7 @@
 #'   - Generates **expected values** (conditional average) on the **link scale**.
 #'   - The uncertainty interval is a *confidence interval*.
 #'   - By default, values are computed using a reference grid spanning the
-#'     observed range of predictor values (see [visualisation_matrix()]).
+#'     observed range of predictor values (see [insight::get_datagrid()]).
 #'
 #' - **`estimate_prediction()`**:
 #'   - Generates **predicted values** (for individual cases) on the **response scale**.
@@ -94,16 +117,14 @@
 #'   - Generates **expected values** (conditional average) on the **response scale**.
 #'   - The uncertainty interval is a *confidence interval*.
 #'   - By default, values are computed using a reference grid spanning the
-#'     observed range of predictor values (see [visualisation_matrix()]).
-#'
-#' `estimate_response()` is a deprecated alias for `estimate_expectation()`.
+#'     observed range of predictor values (see [insight::get_datagrid()]).
 #'
 #' @section Data for predictions:
 #'
 #' If the `data = NULL`, values are estimated using the data used to fit the
 #' model. If `data = "grid"`, values are computed using a reference grid
 #' spanning the observed range of predictor values with
-#' [visualisation_matrix()]. This can be useful for model visualization. The
+#' [insight::get_datagrid()]. This can be useful for model visualization. The
 #' number of predictor values used for each variable can be controlled with the
 #' `length` argument. `data` can also be a data frame containing columns with
 #' names matching the model frame (see [insight::get_data()]). This can be used
@@ -128,32 +149,59 @@
 #' examples](https://easystats.github.io/modelbased/index.html#features) for
 #' various examples, tutorials and usecases.
 #'
-#' @inheritParams estimate_means
+#' @inheritParams get_emmeans
 #' @inheritParams bayestestR::describe_posterior
 #' @param data A data frame with model's predictors to estimate the response. If
-#'   `NULL`, the model's data is used. If "grid", the model matrix is obtained
-#'   (through [insight::get_datagrid()]).
+#' `NULL`, the model's data is used. If `"grid"`, the model matrix is obtained
+#' (through [insight::get_datagrid()]).
+#' @param by The predictor variable(s) at which to estimate the response. Other
+#' predictors of the model that are not included here will be set to their mean
+#' value (for numeric predictors), reference level (for factors) or mode (other
+#' types). The `by` argument will be used to create a data grid via
+#' `insight::get_datagrid()`, which will then be used as `data` argument. Thus,
+#' you cannot specify both `data` and `by` but only of these two arguments.
+#' @param predict This parameter controls what is predicted (and gets internally
+#' passed to [insight::get_predicted()]). In most cases, you don't need to care
+#' about it: it is changed automatically according to the different predicting
+#' functions (i.e., `estimate_expectation()`, `estimate_prediction()`, `estimate_link()`
+#' or `estimate_relation()`). The only time you might be interested in manually
+#' changing it is to estimate other distributional parameters (called "dpar" in
+#' other packages) - for instance when using complex formulae in `brms` models.
+#' The `predict` argument can then be set to the parameter you want to
+#' estimate, for instance `"sigma"`, `"kappa"`, etc. Note that the distinction
+#' between `"expectation"`, `"link"` and `"prediction"` does not then apply (as
+#' you are directly predicting the value of some distributional parameter), and
+#' the corresponding functions will then only differ in the default value of
+#' their `data` argument.
+#' @param transform A function applied to predictions and confidence intervals
+#' to (back-) transform results, which can be useful in case the regression
+#' model has a transformed response variable (e.g., `lm(log(y) ~ x)`). Can also
+#' be `TRUE`, in which case `insight::get_transformation()` is called to
+#' determine the appropriate transformation-function. **Note:** Standard errors
+#' are not (back-) transformed!
 #' @param ... You can add all the additional control arguments from
-#'   [insight::get_datagrid()] (used when `data = "grid"`) and
-#'   [insight::get_predicted()].
+#' [insight::get_datagrid()] (used when `data = "grid"`) and
+#' [insight::get_predicted()].
 #'
-#' @examples
+#' @return A data frame of predicted values and uncertainty intervals, with
+#' class `"estimate_predicted"`. Methods for [`visualisation_recipe()`][visualisation_recipe.estimate_predicted]
+#' and [`plot()`][visualisation_recipe.estimate_predicted] are available.
+#'
+#' @examplesIf all(insight::check_if_installed(c("see", "lme4", "rstanarm"), quietly = TRUE))
 #' library(modelbased)
 #'
 #' # Linear Models
 #' model <- lm(mpg ~ wt, data = mtcars)
 #'
 #' # Get predicted and prediction interval (see insight::get_predicted)
-#' estimate_response(model)
+#' estimate_expectation(model)
 #'
 #' # Get expected values with confidence interval
 #' pred <- estimate_relation(model)
 #' pred
 #'
 #' # Visualisation (see visualisation_recipe())
-#' if (require("see")) {
-#'   plot(pred)
-#' }
+#' plot(pred)
 #'
 #' # Standardize predictions
 #' pred <- estimate_relation(lm(mpg ~ wt + am, data = mtcars))
@@ -163,74 +211,68 @@
 #'
 #' # Logistic Models
 #' model <- glm(vs ~ wt, data = mtcars, family = "binomial")
-#' estimate_response(model)
+#' estimate_expectation(model)
 #' estimate_relation(model)
 #'
 #' # Mixed models
-#' if (require("lme4")) {
-#'   model <- lmer(mpg ~ wt + (1 | gear), data = mtcars)
-#'   estimate_response(model)
-#'   estimate_relation(model)
-#' }
+#' model <- lme4::lmer(mpg ~ wt + (1 | gear), data = mtcars)
+#' estimate_expectation(model)
+#' estimate_relation(model)
 #'
 #' # Bayesian models
 #' \donttest{
-#' if (require("rstanarm")) {
-#'   model <- suppressWarnings(rstanarm::stan_glm(
-#'     mpg ~ wt,
-#'     data = mtcars, refresh = 0, iter = 200
-#'   ))
-#'   estimate_response(model)
-#'   estimate_relation(model)
+#' model <- suppressWarnings(rstanarm::stan_glm(
+#'   mpg ~ wt,
+#'   data = mtcars, refresh = 0, iter = 200
+#' ))
+#' estimate_expectation(model)
+#' estimate_relation(model)
 #' }
-#' }
-#' @return A data frame of predicted values and uncertainty intervals, with
-#' class `"estimate_predicted"`. Methods for [`visualisation_recipe()`][visualisation_recipe.estimate_predicted]
-#' and [`plot()`][visualisation_recipe.estimate_predicted] are available.
 #' @export
 estimate_expectation <- function(model,
                                  data = NULL,
+                                 by = NULL,
+                                 predict = "expectation",
                                  ci = 0.95,
+                                 transform = NULL,
                                  keep_iterations = FALSE,
                                  ...) {
   .estimate_predicted(
     model,
     data = data,
+    by = by,
     ci = ci,
     keep_iterations = keep_iterations,
-    predict = "expectation",
+    predict = predict,
+    transform = transform,
     ...
   )
 }
 
 
-#' @rdname estimate_expectation
-#' @export
-estimate_response <- function(...) {
-  #  TODO: If estimate_response() is removed, document `NULL` with this text.
-  insight::format_alert(
-    "`estimate_response()` is deprecated.",
-    "Please use `estimate_expectation()` (for conditional expected values) or `estimate_prediction()` (for individual case predictions) instead." # nolint
-  )
-  estimate_expectation(...)
-}
-
-
-
-
 #' @rdname estimate_expectation
 #' @export
 estimate_link <- function(model,
                           data = "grid",
+                          by = NULL,
+                          predict = "link",
                           ci = 0.95,
+                          transform = NULL,
                           keep_iterations = FALSE,
                           ...) {
+  # reset to NULL if only "by" was specified
+  if (missing(data) && !missing(by)) {
+    data <- NULL
+  }
+
   .estimate_predicted(
     model,
     data = data,
+    by = by,
     ci = ci,
     keep_iterations = keep_iterations,
-    predict = "link",
+    predict = predict,
+    transform = transform,
     ...
   )
 }
@@ -239,15 +281,20 @@ estimate_link <- function(model,
 #' @export
 estimate_prediction <- function(model,
                                 data = NULL,
+                                by = NULL,
+                                predict = "prediction",
                                 ci = 0.95,
+                                transform = NULL,
                                 keep_iterations = FALSE,
                                 ...) {
   .estimate_predicted(
     model,
     data = data,
+    by = by,
     ci = ci,
     keep_iterations = keep_iterations,
-    predict = "prediction",
+    predict = predict,
+    transform = transform,
     ...
   )
 }
@@ -256,33 +303,50 @@ estimate_prediction <- function(model,
 #' @export
 estimate_relation <- function(model,
                               data = "grid",
+                              by = NULL,
+                              predict = "expectation",
                               ci = 0.95,
+                              transform = NULL,
                               keep_iterations = FALSE,
                               ...) {
+  # reset to NULL if only "by" was specified
+  if (missing(data) && !missing(by)) {
+    data <- NULL
+  }
+
   .estimate_predicted(
     model,
     data = data,
+    by = by,
     ci = ci,
     keep_iterations = keep_iterations,
-    predict = "expectation",
+    predict = predict,
+    transform = transform,
     ...
   )
 }
 
 
-
 # Internal ----------------------------------------------------------------
 
 #' @keywords internal
 .estimate_predicted <- function(model,
                                 data = "grid",
+                                by = NULL,
                                 predict = "expectation",
                                 ci = 0.95,
+                                transform = NULL,
                                 keep_iterations = FALSE,
                                 ...) {
+  # only "by" or "data", but not both
+  if (!is.null(by) && !is.null(data)) {
+    insight::format_error("You can only specify one of `by` or `data`, but not both.")
+  }
+
   # call "get_data()" only once...
-  model_data <- insight::get_data(model)
+  model_data <- insight::get_data(model, verbose = FALSE)
   is_model <- insight::is_model(model)
+  dots <- list(...)
 
   # model and data properties
   if (is_model) {
@@ -290,11 +354,18 @@ estimate_relation <- function(model,
     variables <- insight::find_predictors(model, effects = "all", flatten = TRUE)
     model_response <- insight::find_response(model)
     is_nullmodel <- insight::is_nullmodel(model)
+    grouplevel_effects <- insight::find_random(model, flatten = TRUE, split_nested = TRUE)
   } else {
     # for stuff like data frame, no response and no null model
     variables <- colnames(model_data)
     model_response <- NULL
     is_nullmodel <- FALSE
+    grouplevel_effects <- NULL
+  }
+
+  # if "by" is provided, get datagrid
+  if (!is.null(by)) {
+    data <- insight::get_datagrid(model, by = by, include_response = is_nullmodel, ...)
   }
 
   is_grid <- identical(data, "grid")
@@ -328,7 +399,7 @@ estimate_relation <- function(model,
     data <- model_data
   } else if (!is.data.frame(data)) {
     if (is_grid) {
-      data <- visualisation_matrix(model, reference = model_data, include_response = is_nullmodel, ...)
+      data <- insight::get_datagrid(model, reference = model_data, include_response = is_nullmodel, ...)
     } else {
       insight::format_error(
         "The `data` argument must either NULL, \"grid\" or another data frame."
@@ -356,32 +427,66 @@ estimate_relation <- function(model,
   data <- datawizard::data_restoretype(data, model_data)
 
   # Get predicted ----------------
-  predictions <- insight::get_predicted(model,
+  prediction_args <- list(
+    model,
     data = data,
     predict = predict,
-    ci = ci,
-    ...
+    ci = ci
   )
+  # for predicting grouplevel random effects, add "allow.new.levels"
+  if (!is.null(grouplevel_effects) && any(grouplevel_effects %in% grid_specs$at_spec$varname)) {
+    prediction_args$allow.new.levels <- TRUE
+    dots$allow.new.levels <- NULL
+  }
+  predictions <- do.call(insight::get_predicted, c(prediction_args, dots))
   out <- as.data.frame(predictions, keep_iterations = keep_iterations)
-  out <- cbind(data, out)
+
+  # select columns to copy - we don't want duplicates from the data grid
+  columns_to_copy <- setdiff(colnames(data), colnames(out))
+  if (length(columns_to_copy)) {
+    out <- cbind(data[columns_to_copy], out)
+  }
 
   # remove response variable from data frame, as this variable is predicted
   if (!is.null(model_response) && model_response %in% colnames(out)) {
     out[[model_response]] <- NULL
   }
 
+  # clean-up: remove "Row" variable (from ordinal and alike)
+  out[["Row"]] <- NULL
+
   # Add residuals
   if (!is.null(response)) {
     out$Residuals <- response - out$Predicted
   }
 
+  # transform reponse?
+  if (isTRUE(transform)) {
+    transform <- insight::get_transformation(model, verbose = FALSE)$inverse
+  }
+  if (!is.null(transform)) {
+    out$Predicted <- transform(out$Predicted)
+    out$CI_low <- transform(out$CI_low)
+    out$CI_high <- transform(out$CI_high)
+  }
+
   # Store relevant information
   attr(out, "ci") <- ci
   attr(out, "keep_iterations") <- keep_iterations
   attr(out, "response") <- model_response
   attr(out, "model") <- model
-  attr(out, "table_title") <- c(paste0("Model-based ", tools::toTitleCase(predict)), "blue")
-  attr(out, "table_footer") <- .estimate_predicted_footer(model, grid_specs, out)
+  attr(out, "datagrid") <- data
+  attr(out, "focal_terms") <- grid_specs$at_specs$varname
+  attr(out, "preserve_range") <- grid_specs$preserve_range
+  attr(out, "table_title") <- c("Model-based Predictions", "blue")
+  attr(out, "table_footer") <- .table_footer(
+    out,
+    by = grid_specs$at,
+    type = "predictions",
+    model = model,
+    info = c(grid_specs, list(predict = predict))
+  )
+
   attributes(out) <- c(attributes(out), grid_specs[!names(grid_specs) %in% names(attributes(out))])
 
   # Class
@@ -389,37 +494,3 @@ estimate_relation <- function(model,
 
   out
 }
-
-
-
-# Utils -------------------------------------------------------------------
-
-#' @keywords internal
-.estimate_predicted_footer <- function(model, grid_specs, predictions) {
-  footer <- paste0("\nVariable predicted: ", insight::find_response(model), "\n")
-
-  if ("at" %in% names(grid_specs)) {
-    footer <- paste0(footer, "Predictors modulated: ", toString(grid_specs$at), "\n")
-  }
-
-  if ("adjusted_for" %in% names(grid_specs) &&
-    length(grid_specs$adjusted_for) >= 1 &&
-    !(length(grid_specs$adjusted_for) == 1 && is.na(grid_specs$adjusted_for))) {
-    # if we have values of adjusted terms, add these here
-    if (all(grid_specs$adjusted_for %in% colnames(predictions))) {
-      # get values at which non-focal terms are hold constant
-      adjusted_values <- sapply(grid_specs$adjusted_for, function(i) {
-        predictions[[i]][1]
-      })
-      # at values to names of non-focal terms (footer)
-      if (is.numeric(adjusted_values)) {
-        grid_specs$adjusted_for <- sprintf("%s (%.2g)", grid_specs$adjusted_for, adjusted_values)
-      } else {
-        grid_specs$adjusted_for <- sprintf("%s (%s)", grid_specs$adjusted_for, adjusted_values)
-      }
-    }
-    footer <- paste0(footer, "Predictors controlled: ", toString(grid_specs$adjusted_for), "\n")
-  }
-
-  c(footer, "blue")
-}
